<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Student extends CI_Controller
{

	public function __construct()
	{
		parent:: __construct();
		$this->load->Model('Model');
		$this->load->Model('Token');
	}

	public function login()
	{
		if ($this->input->get_request_header('APP-PUBLIC-TOKEN', true) != APP_PUBLIC_TOKEN) {

			$response = array(
				'responsecode' => '401',
				'status' => 'Unauthorised Access to Resources',
				'message' => 'Access Token is Invalid or Missing'
			);

			$this->output->set_header('Cache-Control: no-store, no-cache, must-revalidate')->set_header('Cache-Control: post-check=0, pre-check=0')->set_header('Pragma: no-cache')->set_status_header(401)->set_content_type('application/json', 'utf-8')->set_output(json_encode($response, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES))->_display();
			exit;

		}

		$data['sAdmNo'] = $this->input->post('sAdmNo');
		$data['sPwd'] = sha1($this->input->post('sPwd'));

		$where = array("sAdmNo" => $data['sAdmNo'], "sPwd" => $data['sPwd']);
		$this->db->where($where);
		$query = $this->db->get('student');
		$count_row = $query->num_rows();

		if ($count_row != 1 || $count_row == 0) {

			$response = array(
				'responsecode' => '200',
				'status' => 'fail',
				'message' => "User not registered"
			);

		} else {
			$studentData = $query->row_array();

			$tokenData['sToken'] = sha1(random_string('md5', 100));

			date_default_timezone_set("Asia/Kolkata");
			$tokenData['suDate'] = date("Y-m-d h:i:s");
			$tokenData['sFcmId'] = $this->input->post('sFcmId');

			$this->db->where('sAdmNo', $studentData['sAdmNo']);
			$this->db->update('student', $tokenData);

			if ($this->db->affected_rows() != 1) {

				//print_r($this->db->affected_rows());
				$response = array(
					'responsecode' => '200',
					'status' => 'tokenerror',
					'message' => "Unable to process request token"
				);

			} elseif ($this->db->affected_rows() == 1) {

				$studentData['sFcmId'] = $tokenData['sFcmId'];
				$studentData['sToken'] = $tokenData['sToken'];
				$studentData['suDate'] = $tokenData['suDate'];
				$studentData['sPwd'] = "";

//				echo '<pre>';
//				print_r($tokenData);

				$response = array(
					'responsecode' => '200',
					'status' => 'token-created',
					'message' => "Access token generated successfully",
					'studentDetail' => $studentData
				);

			}

		}

		$this->output->set_header('Cache-Control: no-store, no-cache, must-revalidate')
			->set_header('Cache-Control: post-check=0, pre-check=0')
			->set_header('Pragma: no-cache')->set_status_header(200)
			->set_content_type('application/json', 'utf-8')
			->set_output(json_encode($response, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES))->_display();
		exit;

	}

	public function getStudent()
	{
		$token = $this->input->get_request_header('APP-PRIVATE-TOKEN', TRUE);
		$admNo = $this->input->post('sAdmNo');

		if ($this->Token->checkStudentToken($token, $admNo) == false) {

			$response = array(
				'responsecode' => '401',
				'status' => 'Unauthorised Access to Resources',
				'message' => 'Access Token is Invalid or Missing'
			);

			$this->output->set_header('Cache-Control: no-store, no-cache, must-revalidate')->set_header('Cache-Control: post-check=0, pre-check=0')->set_header('Pragma: no-cache')->set_status_header(401)->set_content_type('application/json', 'utf-8')->set_output(json_encode($response, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES))->_display();
			exit;

		} else {

			$where = array("sActive" => '1', "sAdmNo" => $admNo);
			$data['student'] = $this->Model->join_three_where_row("student", "parents", "guardian", ' `parents`.`sFk` = `student`.`sId` ', ' `guardian`.`sFk` = `student`.`sId` ', $where);

			$response = array(
				'responsecode' => '200',
				'status' => 'Success',
				'message' => "Get data successfully",
				'student' => $data['student']
			);

			$this->output->set_header('Cache-Control: no-store, no-cache, must-revalidate')->set_header('Cache-Control: post-check=0, pre-check=0')->set_header('Pragma: no-cache')->set_status_header(200)->set_content_type('application/json', 'utf-8')->set_output(json_encode($response, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES))->_display();
			exit;

		}
	}

	public function getTimeTable()
	{
		$token = $this->input->get_request_header('APP-PRIVATE-TOKEN', TRUE);
		$admNo = $this->input->post('sAdmNo');

		if ($this->Token->checkStudentToken($token, $admNo) == false) {

			$response = array(
				'responsecode' => '401',
				'status' => 'Unauthorised Access to Resources',
				'message' => 'Access Token is Invalid or Missing'
			);

			$this->output->set_header('Cache-Control: no-store, no-cache, must-revalidate')->set_header('Cache-Control: post-check=0, pre-check=0')->set_header('Pragma: no-cache')->set_status_header(401)->set_content_type('application/json', 'utf-8')->set_output(json_encode($response, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES))->_display();
			exit;

		} else {

			$data['stFk'] = $this->input->post('stFk');
			$data['dvFk'] = $this->input->post('dvFk');

			$where = array("ttActive" => '1', "tstFk" => $data['stFk'], "tdvFk" => $data['dvFk']);
			$data['timetable'] = $this->Model->join_three_where("timetable", "teacher", "subject", ' `timetable`.`tFk` = `teacher`.`tUsName` ', ' `timetable`.`sbFk` = `subject`.`sbId` ', $where);

			$response = array(
				'responsecode' => '200',
				'status' => 'Success',
				'message' => "Get data successfully",
				'timetable' => $data['timetable']
			);

			$this->output->set_header('Cache-Control: no-store, no-cache, must-revalidate')->set_header('Cache-Control: post-check=0, pre-check=0')->set_header('Pragma: no-cache')->set_status_header(200)->set_content_type('application/json', 'utf-8')->set_output(json_encode($response, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES))->_display();
			exit;

		}
	}

	public function getFees()
	{
		$token = $this->input->get_request_header('APP-PRIVATE-TOKEN', TRUE);
		$admNo = $this->input->post('sAdmNo');

		if ($this->Token->checkStudentToken($token, $admNo) == false) {

			$response = array(
				'responsecode' => '401',
				'status' => 'Unauthorised Access to Resources',
				'message' => 'Access Token is Invalid or Missing'
			);

			$this->output->set_header('Cache-Control: no-store, no-cache, must-revalidate')->set_header('Cache-Control: post-check=0, pre-check=0')->set_header('Pragma: no-cache')->set_status_header(401)->set_content_type('application/json', 'utf-8')->set_output(json_encode($response, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES))->_display();
			exit;

		} else {

			$data['sFk'] = $this->input->post('sFk');
			$data['stFk'] = $this->input->post('stFk');

			$where = array("sFk" => $data['sFk'], "fstFk" => $data['stFk']);
			$data['feestudent'] = $this->Model->select_where("feestudent", $where);

			$response = array(
				'responsecode' => '200',
				'status' => 'Success',
				'message' => "Get data successfully",
				'feestudent' => $data['feestudent']
			);

			$this->output->set_header('Cache-Control: no-store, no-cache, must-revalidate')->set_header('Cache-Control: post-check=0, pre-check=0')->set_header('Pragma: no-cache')->set_status_header(200)->set_content_type('application/json', 'utf-8')->set_output(json_encode($response, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES))->_display();
			exit;

		}
	}

	public function getFeeStructure()
	{
		$token = $this->input->get_request_header('APP-PRIVATE-TOKEN', TRUE);
		$admNo = $this->input->post('sAdmNo');

		if ($this->Token->checkStudentToken($token, $admNo) == false) {

			$response = array(
				'responsecode' => '401',
				'status' => 'Unauthorised Access to Resources',
				'message' => 'Access Token is Invalid or Missing'
			);

			$this->output->set_header('Cache-Control: no-store, no-cache, must-revalidate')->set_header('Cache-Control: post-check=0, pre-check=0')->set_header('Pragma: no-cache')->set_status_header(401)->set_content_type('application/json', 'utf-8')->set_output(json_encode($response, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES))->_display();
			exit;

		} else {

			$data['stFk'] = $this->input->post('stFk');

			$where = array("stFk" => $data['stFk']);
			$data['feestructure'] = $this->Model->select_where("feestructure", $where);

			$response = array(
				'responsecode' => '200',
				'status' => 'Success',
				'message' => "Get data successfully",
				'feestructure' => $data['feestructure']
			);

			$this->output->set_header('Cache-Control: no-store, no-cache, must-revalidate')->set_header('Cache-Control: post-check=0, pre-check=0')->set_header('Pragma: no-cache')->set_status_header(200)->set_content_type('application/json', 'utf-8')->set_output(json_encode($response, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES))->_display();
			exit;

		}
	}

	public function getAttendance()
	{
		$token = $this->input->get_request_header('APP-PRIVATE-TOKEN', TRUE);
		$admNo = $this->input->post('sAdmNo');

		if ($this->Token->checkStudentToken($token, $admNo) == false) {

			$response = array(
				'responsecode' => '401',
				'status' => 'Unauthorised Access to Resources',
				'message' => 'Access Token is Invalid or Missing'
			);

			$this->output->set_header('Cache-Control: no-store, no-cache, must-revalidate')->set_header('Cache-Control: post-check=0, pre-check=0')->set_header('Pragma: no-cache')->set_status_header(401)->set_content_type('application/json', 'utf-8')->set_output(json_encode($response, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES))->_display();
			exit;

		} else {

			$data['sFk'] = $this->input->post('sFk');
			$data['stFk'] = $this->input->post('stFk');
			$data['dvFk'] = $this->input->post('dvFk');
			$data['atdStDate'] = $this->input->post('atdStDate');
			$data['atdEndDate'] = $this->input->post('atdEndDate');

			$where = array("sFk" => $data['sFk'], "stdFk" => $data['stFk'], "divFk" => $data['dvFk']);
			$data['attendance'] = $this->Model->join_five_where_between_desc(
				'`attendance`.`sFk` = `s`.`sAdmNo`',
				'`attendance`.`stdFk` = `std`.`stId`',
				'`attendance`.`divFk` = `div`.`dId`',
				'`attendance`.`tchrFk` = `tchr`.`tUsName`',
				$data['atdStDate'], $data['atdEndDate'], $where);

			$response = array(
				'responsecode' => '200',
				'status' => 'Success',
				'message' => "Get data successfully",
				'attendance' => $data['attendance']
			);

			$this->output->set_header('Cache-Control: no-store, no-cache, must-revalidate')->set_header('Cache-Control: post-check=0, pre-check=0')->set_header('Pragma: no-cache')->set_status_header(200)->set_content_type('application/json', 'utf-8')->set_output(json_encode($response, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES))->_display();
			exit;

		}
	}

	public function getStudentFee()
	{
		$token = $this->input->get_request_header('APP-PRIVATE-TOKEN', TRUE);
		$admNo = $this->input->post('sAdmNo');

		if ($this->Token->checkStudentToken($token, $admNo) == false) {

			$response = array(
				'responsecode' => '401',
				'status' => 'Unauthorised Access to Resources',
				'message' => 'Access Token is Invalid or Missing'
			);

			$this->output->set_header('Cache-Control: no-store, no-cache, must-revalidate')->set_header('Cache-Control: post-check=0, pre-check=0')->set_header('Pragma: no-cache')->set_status_header(401)->set_content_type('application/json', 'utf-8')->set_output(json_encode($response, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES))->_display();
			exit;

		} else {

			$where = array("sAdmNo" => $admNo);
			$data['studentfee'] = $this->Model->join_four_where_order("feestudent", "student", "standard", "division", ' `feestudent`.`sFk` = `student`.`sAdmNo` ', ' `feestudent`.`fstFk` = `standard`.`stId` ', ' `feestudent`.`fdvFk` = `division`.`dId` ', $where, 'fscDate', 'desc');

			$response = array(
				'responsecode' => '200',
				'status' => 'Success',
				'message' => "Get data successfully",
				'studentfee' => $data['studentfee']
			);

			$this->output->set_header('Cache-Control: no-store, no-cache, must-revalidate')->set_header('Cache-Control: post-check=0, pre-check=0')->set_header('Pragma: no-cache')->set_status_header(200)->set_content_type('application/json', 'utf-8')->set_output(json_encode($response, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES))->_display();
			exit;

		}
	}

	public function getTransport()
	{
		$token = $this->input->get_request_header('APP-PRIVATE-TOKEN', TRUE);
		$admNo = $this->input->post('sAdmNo');

		if ($this->Token->checkStudentToken($token, $admNo) == false) {

			$response = array(
				'responsecode' => '401',
				'status' => 'Unauthorised Access to Resources',
				'message' => 'Access Token is Invalid or Missing'
			);

			$this->output->set_header('Cache-Control: no-store, no-cache, must-revalidate')->set_header('Cache-Control: post-check=0, pre-check=0')->set_header('Pragma: no-cache')->set_status_header(401)->set_content_type('application/json', 'utf-8')->set_output(json_encode($response, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES))->_display();
			exit;

		} else {

			$data['trId'] = $this->input->post('trId');

			$where = array("trActive" => '1', "trId" => $data['trId']);
			$data['transport'] = $this->Model->select_where_row("transport", $where);

			$response = array(
				'responsecode' => '200',
				'status' => 'Success',
				'message' => "Get data successfully",
				'transport' => $data['transport']
			);

			$this->output->set_header('Cache-Control: no-store, no-cache, must-revalidate')->set_header('Cache-Control: post-check=0, pre-check=0')->set_header('Pragma: no-cache')->set_status_header(200)->set_content_type('application/json', 'utf-8')->set_output(json_encode($response, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES))->_display();
			exit;

		}
	}

	public function addFee()
	{
		$token = $this->input->get_request_header('APP-PRIVATE-TOKEN', TRUE);
		$admNo = $this->input->post('sAdmNo');

		if ($this->Token->checkStudentToken($token, $admNo) == false) {

			$response = array(
				'responsecode' => '401',
				'status' => 'Unauthorised Access to Resources',
				'message' => 'Access Token is Invalid or Missing'
			);

			$this->output->set_header('Cache-Control: no-store, no-cache, must-revalidate')->set_header('Cache-Control: post-check=0, pre-check=0')->set_header('Pragma: no-cache')->set_status_header(401)->set_content_type('application/json', 'utf-8')->set_output(json_encode($response, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES))->_display();
			exit;

		} else {

			$data['payId'] = $this->input->post('payId');
			$data['payType'] = $this->input->post('payType');

			$feeData = $this->input->post('feeData[]');

			$fData = json_decode($feeData);

			date_default_timezone_set("Asia/Kolkata");

			$data['fscDate'] = date("Y-m-d h:i:s");

			$value = array();
			foreach ($fData as $res) {
				array_push($value, array(
					"fFk" => $res->fFk,
					"sFk" => $res->sFk,
					"fstFk" => $res->fstFk,
					"fdvFk" => $res->dvFk,
					"fsTotal" => $res->fsTotal,
					"fsMonth" => $res->fsMonth,
					"fsMonPrice" => $res->fsMonPrice,
					"fsPaymentId" => $data['payId'],
					"fsPayType" => $data['payType'],
					"fsBus" => $res->fsBus,
					"fscDate" => $data['fscDate']
				));
			}

			$insFee = $this->Model->insert_batch("feestudent", $value);

			if ($insFee) {
				$response = array(
					'responsecode' => '200',
					'status' => 'Success',
					'message' => "Fees paid successfully"
				);
			} else {
				$response = array(
					'responsecode' => '200',
					'status' => 'fail',
					'message' => "Unable to paid fees"
				);
			}

			$this->output->set_header('Cache-Control: no-store, no-cache, must-revalidate')->set_header('Cache-Control: post-check=0, pre-check=0')->set_header('Pragma: no-cache')->set_status_header(200)->set_content_type('application/json', 'utf-8')->set_output(json_encode($response, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES))->_display();
			exit;

		}
	}

	public function getAllAssignment()
	{
		$token = $this->input->get_request_header('APP-PRIVATE-TOKEN', TRUE);
		$admNo = $this->input->post('sAdmNo');

		if ($this->Token->checkStudentToken($token, $admNo) == false) {

			$response = array(
				'responsecode' => '401',
				'status' => 'Unauthorised Access to Resources',
				'message' => 'Access Token is Invalid or Missing'
			);

			$this->output->set_header('Cache-Control: no-store, no-cache, must-revalidate')->set_header('Cache-Control: post-check=0, pre-check=0')->set_header('Pragma: no-cache')->set_status_header(401)->set_content_type('application/json', 'utf-8')->set_output(json_encode($response, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES))->_display();
			exit;

		} else {

			$data['stFk'] = $this->input->post('stFk');
			$data['dvFk'] = $this->input->post('dvFk');
			$limit = $this->input->post('limit');
			$offset = $this->input->post('offset');

			$where = array("asstFk" => $data['stFk'], "asdvFk" => $data['dvFk']);
			$data['assignment'] = $this->Model->join_where_order_limit("assignment", "subject", '`assignment`.`assubFk` = `subject`.`sbId`', $where, 'asuDate', 'desc', $limit, $offset);

			$response = array(
				'responsecode' => '200',
				'status' => 'Success',
				'message' => "Get data successfully",
				'assignment' => $data['assignment']
			);

			$this->output->set_header('Cache-Control: no-store, no-cache, must-revalidate')->set_header('Cache-Control: post-check=0, pre-check=0')->set_header('Pragma: no-cache')->set_status_header(200)->set_content_type('application/json', 'utf-8')->set_output(json_encode($response, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES))->_display();
			exit;

		}
	}

	public function getAllStudentActivity()
	{
		$token = $this->input->get_request_header('APP-PRIVATE-TOKEN', TRUE);
		$admNo = $this->input->post('sAdmNo');

		if ($this->Token->checkStudentToken($token, $admNo) == false) {

			$response = array(
				'responsecode' => '401',
				'status' => 'Unauthorised Access to Resources',
				'message' => 'Access Token is Invalid or Missing'
			);

			$this->output->set_header('Cache-Control: no-store, no-cache, must-revalidate')->set_header('Cache-Control: post-check=0, pre-check=0')->set_header('Pragma: no-cache')->set_status_header(401)->set_content_type('application/json', 'utf-8')->set_output(json_encode($response, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES))->_display();
			exit;

		} else {

			$data['stFk'] = $this->input->post('stFk');
			$data['dvFk'] = $this->input->post('dvFk');
			$limit = $this->input->post('limit');
			$offset = $this->input->post('offset');

			$where = array("sastFk" => $data['stFk'], "sadvFk" => $data['dvFk']);
			$data['studentactivity'] = $this->Model->join_where_order_limit("studentactivity", "teacher", '`studentactivity`.`satFk` = `teacher`.`tUsName`', $where, 'sacDate', 'desc', $limit, $offset);

			$response = array(
				'responsecode' => '200',
				'status' => 'Success',
				'message' => "Get data successfully",
				'studentactivity' => $data['studentactivity']
			);

			$this->output->set_header('Cache-Control: no-store, no-cache, must-revalidate')->set_header('Cache-Control: post-check=0, pre-check=0')->set_header('Pragma: no-cache')->set_status_header(200)->set_content_type('application/json', 'utf-8')->set_output(json_encode($response, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES))->_display();
			exit;

		}
	}

}
